==> kdepim_4.13.3.orig.tar.xz: kdepim-4.13.3/libkleo/backends/qgpgme/qgpgmeadduseridjob.cpp <==
/*
    qgpgmeadduseridjob.cpp

    This file is part of libkleopatra, the KDE keymanagement library
    Copyright (c) 2008 Klarälvdalens Datakonsult AB

    Libkleopatra is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.

    Libkleopatra is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

    In addition, as a special exception, the copyright holders give
    permission to link the code of this program with any edition of
    the Qt library by Trolltech AS, Norway (or with modified versions
    of Qt that use the same license as Qt), and distribute linked
    combinations including the two.  You must obey the GNU General
    Public License in all respects for all of the code used other than
    Qt.  If you modify this file, you may extend this exception to
    your version of the file, but you are not obligated to do so.  If
    you do not wish to do so, delete this exception statement from
    your version.
*/

#include "qgpgmeadduseridjob.h"

#include <qgpgme/dataprovider.h>

#include <gpgme++/context.h>
#include <gpgme++/data.h>
#include <gpgme++/gpgadduserideditinteractor.h>
#include <gpgme++/key.h>

#include <cassert>
#include <memory>

using namespace Kleo;
using namespace GpgME;
using namespace boost;

QGpgMEAddUserIDJob::QGpgMEAddUserIDJob( Context * context )
  : mixin_type( context )
{
  lateInitialization();
}

QGpgMEAddUserIDJob::~QGpgMEAddUserIDJob() {}

static QGpgMEAddUserIDJob::result_type add_user_id( Context * ctx, const Key & key, const QString & name, const QString & email, const QString & comment ) {

  std::auto_ptr<GpgAddUserIDEditInteractor> gau( new GpgAddUserIDEditInteractor );

  gau->setNameUtf8(       name.toUtf8().constData() );
  gau->setEmailUtf8(     email.toUtf8().constData() );
  gau->setCommentUtf8( comment.toUtf8().constData() );

  std::auto_ptr<EditInteractor> ei( gau );

  QGpgME::QByteArrayDataProvider dp;
  Data data( &dp );
  assert( !data.isNull() );
  const Error err = ctx->edit( key, ei, data );
  Error ae;
  const QString log = _detail::audit_log_as_html( ctx, ae );
  return make_tuple( err, log, ae );
}

Error QGpgMEAddUserIDJob::start( const Key & key, const QString & name, const QString & email, const QString & comment ) {
  run( bind( &add_user_id, _1, key, name, email, comment ) );
  return Error();
}

==> kdepim-4.14.11_pre20160611.tar.xz: kdepim-4.14.11_pre20160611/libkleo/backends/qgpgme/qgpgmeadduseridjob.cpp <==
/*
    qgpgmeadduseridjob.cpp

    This file is part of libkleopatra, the KDE keymanagement library
    Copyright (c) 2008 Klarälvdalens Datakonsult AB

    Libkleopatra is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.

    Libkleopatra is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

    In addition, as a special exception, the copyright holders give
    permission to link the code of this program with any edition of
    the Qt library by Trolltech AS, Norway (or with modified versions
    of Qt that use the same license as Qt), and distribute linked
    combinations including the two.  You must obey the GNU General
    Public License in all respects for all of the code used other than
    Qt.  If you modify this file, you may extend this exception to
    your version of the file, but you are not obligated to do so.  If
    you do not wish to do so, delete this exception statement from
    your version.
*/

#include "qgpgmeadduseridjob.h"

#include <kde4_qgpgme/dataprovider.h>

#include <kde4_gpgme++/context.h>
#include <kde4_gpgme++/data.h>
#include <kde4_gpgme++/gpgadduserideditinteractor.h>
#include <kde4_gpgme++/key.h>

#include <cassert>
#include <memory>

using namespace Kleo;
using namespace GpgME;
using namespace boost;

QGpgMEAddUserIDJob::QGpgMEAddUserIDJob( Context * context )
  : mixin_type( context )
{
  lateInitialization();
}

QGpgMEAddUserIDJob::~QGpgMEAddUserIDJob() {}

static QGpgMEAddUserIDJob::result_type add_user_id( Context * ctx, const Key & key, const QString & name, const QString & email, const QString & comment ) {

  std::auto_ptr<GpgAddUserIDEditInteractor> gau( new GpgAddUserIDEditInteractor );

  gau->setNameUtf8(       name.toUtf8().constData() );
  gau->setEmailUtf8(     email.toUtf8().constData() );
  gau->setCommentUtf8( comment.toUtf8().constData() );

  std::auto_ptr<EditInteractor> ei( gau );

  QGpgME::QByteArrayDataProvider dp;
  Data data( &dp );
  assert( !data.isNull() );
  const Error err = ctx->edit( key, ei, data );
  Error ae;
  const QString log = _detail::audit_log_as_html( ctx, ae );
  return make_tuple( err, log, ae );
}

Error QGpgMEAddUserIDJob::start( const Key & key, const QString & name, const QString & email, const QString & comment ) {
  run( bind( &add_user_id, _1, key, name, email, comment ) );
  return Error();
}
